ProvisioningArtifactPreferences class
The user-defined preferences that will be applied during product
provisioning, unless overridden by ProvisioningPreferences or
UpdateProvisioningPreferences.
For more information on maximum concurrent accounts and failure tolerance, see Stack set operation options in the AWS CloudFormation User Guide.
Constructors
-
ProvisioningArtifactPreferences({List<
String> ? stackSetAccounts, List<String> ? stackSetRegions}) -
ProvisioningArtifactPreferences.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stackSetAccounts
→ List<
String> ? -
One or more AWS accounts where stack instances are deployed from the stack
set. These accounts can be scoped in
ProvisioningPreferences$StackSetAccountsandUpdateProvisioningPreferences$StackSetAccounts.final -
stackSetRegions
→ List<
String> ? -
One or more AWS Regions where stack instances are deployed from the stack
set. These regions can be scoped in
ProvisioningPreferences$StackSetRegionsandUpdateProvisioningPreferences$StackSetRegions.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited